@@ -691,6 +691,7 @@ extern crate void;
 
 pub mod adc;
 pub mod blocking;
+pub mod can;
 pub mod digital;
 pub mod fmt;
 pub mod prelude;
@@ -992,3 +993,7 @@ pub enum Direction {
     /// 1, 2, 3
     Upcounting,
 }
+
+mod private {
+    pub trait Sealed {}
+}
